@@ -526,14 +526,21 @@ int main(int argc, char *argv[])
 	
 	become_daemon();
 	
-	path =    argv[0];
-	map  =    argv[1];
+	path    = argv[0];
+	map     = argv[1];
 	mapargv = &argv[2];
         mapargc = argc-2;         
 
 	syslog(LOG_INFO, "starting automounter version %s, path = %s, "
 	       "maptype = %s, mapname = %s", version, path, map,
-	       (argc < 3) ? "none" : mapargv[0]);
+	       (mapargc < 1) ? "none" : mapargv[0]);
+
+	if ( mapargc ) {
+	  int i;
+	  syslog(LOG_DEBUG, "Map argc = %d", mapargc);
+	  for ( i = 0 ; i < mapargc ; i++ )
+	    syslog(LOG_DEBUG, "Map argv[%d] = %s", i, mapargv[i]);
+	}
 
 	if ( (mapfmt = strchr(map,',')) )
 		*(mapfmt++) = '\0';
